@@ -342,6 +342,21 @@ def get_params(args):
     args.purge_output = args.purge_output is not None and args.purge_output
     return params
 
+class ProgressBar():
+    def __init__(self):
+        self.pbar = None
+
+    def __call__(self, block_num, block_size, total_size):
+        if not self.pbar:
+            self.pbar=progressbar.ProgressBar(maxval=total_size)
+            self.pbar.start()
+
+        downloaded = block_num * block_size
+        if downloaded < total_size:
+            self.pbar.update(downloaded)
+        else:
+            self.pbar.finish()
+
 def check_weight_files():
     parent_dir = os.path.dirname(os.path.abspath(__file__))
     an_weight_file = f"{parent_dir}/weights/weight-roi_0.h5"
@@ -352,15 +367,7 @@ def check_weight_files():
     if not os.path.exists(output_path):
         input_url = "https://github.com/abysslover/deepparcellation/releases/download/v1.0.0/weights.tar.gz"
         import urllib.request
-        with urllib.request.urlopen(input_url) as response, open(output_path, "wb") as out_file:
-            data = response.read()
-            out_file.write(data)
-
-    print(f"[check_weight_files] Uncompress weights: {output_path}")
-    import tarfile    
-    with tarfile.open(output_path, "r") as tar:
-        tar.extractall(path=parent_dir)
-    os.remove(output_path)
+        urllib.request.urlretrieve(input_url, output_path, ProgressBar())
 
 def main():
     check_weight_files()
